nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Rompatchenl

Struct Rompatchenl 

#[repr(transparent)]
pub struct Rompatchenl(pub u32);
ROMC Enable Register Low

Tuple Fields

0: u32

Implementations

Source

impl Rompatchenl

pub const fn enable(&self) -> Enable

Enable Address Comparator - This bit enables the corresponding address comparator to trigger an event

pub const fn set_enable(&mut self, val: Enable)

Enable Address Comparator - This bit enables the corresponding address comparator to trigger an event