#[repr(transparent)]pub struct Rompatchsr(pub u32);Expand description
ROMC Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Rompatchsr
impl Rompatchsr
Sourcepub const fn source(&self) -> Source
pub const fn source(&self) -> Source
ROMC Source Number - Binary encoding of the number of the address comparator which has an address match in the most recent patch event on ROMC AHB
Sourcepub const fn set_source(&mut self, val: Source)
pub const fn set_source(&mut self, val: Source)
ROMC Source Number - Binary encoding of the number of the address comparator which has an address match in the most recent patch event on ROMC AHB